public inbox for netdev@vger.kernel.org
 help / color / mirror / Atom feed
From: Shirley Ma <mashirle@us.ibm.com>
To: jeffrey.t.kirsher@intel.com, gregory.v.rose@intel.com
Cc: "e1000-devel@lists.sourceforge.net"
	<e1000-devel@lists.sourceforge.net>,
	"netdev@vger.kernel.org" <netdev@vger.kernel.org>,
	"davem@davemloft.net" <davem@davemloft.net>,
	"kvm@vger.kernel.org" <kvm@vger.kernel.org>
Subject: [PATCH net-next] ixgbe: make macvlan on PF working when SRIOV is enabled
Date: Tue, 25 May 2010 09:55:09 -0700	[thread overview]
Message-ID: <1274806509.18023.58.camel@localhost.localdomain> (raw)

When SRIOV is enabled, if we create macvlan on PF and load the VF driver in host 
domain, when macvlan/PF and VF interfaces are all up, the macvlan incoming network
traffics are directed to VF interface not PF interface. This patch has fixed this
issue.

Signed-off-by: Shirley Ma <xma@us.ibm.com>
--- 
 drivers/net/ixgbe/ixgbe_common.c |   26 ++++++++++++++++----------
 1 files changed, 16 insertions(+), 10 deletions(-)

diff --git a/drivers/net/ixgbe/ixgbe_common.c b/drivers/net/ixgbe/ixgbe_common.c
index 1159d91..591dd19 100644
--- a/drivers/net/ixgbe/ixgbe_common.c
+++ b/drivers/net/ixgbe/ixgbe_common.c
@@ -1271,6 +1271,7 @@ s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw)
 {
 	u32 i;
 	u32 rar_entries = hw->mac.num_rar_entries;
+	struct ixgbe_adapter *adapter = hw->back;
 
 	/*
 	 * If the current mac address is valid, assume it is a software override
@@ -1288,15 +1289,18 @@ s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw)
 		hw_dbg(hw, "Overriding MAC Address in RAR[0]\n");
 		hw_dbg(hw, " New MAC Addr =%pM\n", hw->mac.addr);
 
-		hw->mac.ops.set_rar(hw, 0, hw->mac.addr, 0, IXGBE_RAH_AV);
+		hw->mac.ops.set_rar(hw, 0, hw->mac.addr, adapter->num_vfs,
+				    IXGBE_RAH_AV);
 	}
 	hw->addr_ctrl.overflow_promisc = 0;
 
-	hw->addr_ctrl.rar_used_count = 1;
+	/* reserve VFs receive address entries if any */
+	hw->addr_ctrl.rar_used_count = adapter->num_vfs + 1;
 
-	/* Zero out the other receive addresses. */
-	hw_dbg(hw, "Clearing RAR[1-%d]\n", rar_entries - 1);
-	for (i = 1; i < rar_entries; i++) {
+	/* Zero out the other receive addresses except VFs if any */
+	hw_dbg(hw, "Clearing RAR[%d-%d]\n",
+	       adapter->num_vfs + 1, rar_entries - 1);
+	for (i = adapter->num_vfs + 1; i < rar_entries; i++) {
 		IXGBE_WRITE_REG(hw, IXGBE_RAL(i), 0);
 		IXGBE_WRITE_REG(hw, IXGBE_RAH(i), 0);
 	}
@@ -1368,18 +1372,20 @@ s32 ixgbe_update_uc_addr_list_generic(struct ixgbe_hw *hw,
 	u32 uc_addr_in_use;
 	u32 fctrl;
 	struct netdev_hw_addr *ha;
+	struct ixgbe_adapter *adapter = hw->back;
 
 	/*
 	 * Clear accounting of old secondary address list,
 	 * don't count RAR[0]
 	 */
-	uc_addr_in_use = hw->addr_ctrl.rar_used_count - 1;
+	uc_addr_in_use = hw->addr_ctrl.rar_used_count - 1 - adapter->num_vfs;
 	hw->addr_ctrl.rar_used_count -= uc_addr_in_use;
 	hw->addr_ctrl.overflow_promisc = 0;
 
-	/* Zero out the other receive addresses */
-	hw_dbg(hw, "Clearing RAR[1-%d]\n", uc_addr_in_use + 1);
-	for (i = 0; i < uc_addr_in_use; i++) {
+	/* Zero out the other receive addresses except VFs if any */
+	hw_dbg(hw, "Clearing RAR[%d-%d]\n",
+	       adapter->num_vfs + 1, uc_addr_in_use + adapter->num_vfs + 1);
+	for (i = adapter->num_vfs; i < uc_addr_in_use + adapter->num_vfs; i++) {
 		IXGBE_WRITE_REG(hw, IXGBE_RAL(1+i), 0);
 		IXGBE_WRITE_REG(hw, IXGBE_RAH(1+i), 0);
 	}
@@ -1387,7 +1393,7 @@ s32 ixgbe_update_uc_addr_list_generic(struct ixgbe_hw *hw,
 	/* Add the new addresses */
 	netdev_for_each_uc_addr(ha, netdev) {
 		hw_dbg(hw, " Adding the secondary addresses:\n");
-		ixgbe_add_uc_addr(hw, ha->addr, 0);
+		ixgbe_add_uc_addr(hw, ha->addr, adapter->num_vfs);
 	}
 
 	if (hw->addr_ctrl.overflow_promisc) {




------------------------------------------------------------------------------

_______________________________________________
E1000-devel mailing list
E1000-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/e1000-devel
To learn more about Intel&#174; Ethernet, visit http://communities.intel.com/community/wired

             reply	other threads:[~2010-05-25 16:55 UTC|newest]

Thread overview: 4+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2010-05-25 16:55 Shirley Ma [this message]
2010-05-25 17:15 ` [PATCH net-next] ixgbe: make macvlan on PF working when SRIOV is enabled Shirley Ma
2010-05-25 17:24   ` Rose, Gregory V
2010-05-25 18:37 ` Jeff Kirsher

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1274806509.18023.58.camel@localhost.localdomain \
    --to=mashirle@us.ibm.com \
    --cc=davem@davemloft.net \
    --cc=e1000-devel@lists.sourceforge.net \
    --cc=gregory.v.rose@intel.com \
    --cc=jeffrey.t.kirsher@intel.com \
    --cc=kvm@vger.kernel.org \
    --cc=netdev@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox